@@ -1,7 +1,8 @@
 import os
 from dataclasses import dataclass
 from enum import Enum
-from functools import cache
+from functools import lru_cache
+
 from hashlib import md5
 from itertools import chain
 from pathlib import Path
@@ -201,7 +202,7 @@ class LocalCallParser(SimpleSQLParser[ParsedSqlNode]):
 
 
 class LocalMacroParser(MacroParser):
-    @cache
+    @lru_cache(maxsize=None)
     def parse_remote(self, contents) -> Iterable[ParsedMacro]:
         base = UnparsedMacro(
             path="from local system",
@@ -432,7 +433,7 @@ class DbtOsmosis:
 
         process_node(self.config, self.dbt, node)
 
-    @cache
+    @lru_cache(maxsize=None)
     def _extract_jinja_data(self, sql: str):
         macro_blocks = []
         data_chunks = []
